@@ -421,6 +421,10 @@ struct _cmd_args {
 
         /* For the subdir mount */
         char           *subdir_mount;
+
+        char              *process_name;
+        char              *event_history;
+        int                thin_client;
 };
 typedef struct _cmd_args cmd_args_t;
 
@@ -500,11 +504,9 @@ struct _glusterfs_ctx {
         int                process_mode; /*mode in which process is runninng*/
         struct syncenv    *env;          /* The env pointer to the synctasks */
 
-#if defined(OLD_MEM_POOLS)
         struct list_head   mempool_list; /* used to keep a global list of
                                             mempools, used to log details of
                                             mempool in statedump */
-#endif
         char              *statedump_path;
 
         struct mem_pool   *dict_pool;
